@@ -3,7 +3,7 @@ set -e
 
 mkdir build
 cd build
-cmake ..
+cmake -Wno-dev ..
 for i in \
     test_contactid test_dbschema test_friendmessagedispatcher \
     test_groupmessagedispatcher test_messageprocessor test_offlinemsgengine \
